@@ -11,21 +11,22 @@ import invoke.program
 
 class Init:
     "__init__"
+
     def dunder_version_info(self):
-        assert hasattr(invoke, '__version_info__')
+        assert hasattr(invoke, "__version_info__")
         ver = invoke.__version_info__
         assert isinstance(ver, tuple)
         assert all(isinstance(x, int) for x in ver)
 
     def dunder_version(self):
-        assert hasattr(invoke, '__version__')
+        assert hasattr(invoke, "__version__")
         ver = invoke.__version__
         assert isinstance(ver, six.string_types)
-        assert re.match(r'\d+\.\d+\.\d+', ver)
+        assert re.match(r"\d+\.\d+\.\d+", ver)
 
     def dunder_version_looks_generated_from_dunder_version_info(self):
         # Meh.
-        ver_part = invoke.__version__.split('.')[0]
+        ver_part = invoke.__version__.split(".")[0]
         ver_info_part = invoke.__version_info__[0]
         assert ver_part == str(ver_info_part)
 
